This mod is a utility for other mods to utilise MonoBehaviour field serialisation injection.

## Instructions for players

 - To install the mod, just extract `FieldInjector.dll` into your `Mods` folder.

## Instructions for programmers

If you want to utilise custom MonoBehaviours with properly serialised fields from asset bundles, reference this mod as a dependency.

### Writing a custom MonoBehaviour

This is fairly simple, and there is very little difference between a normal unity MonoBehaviour and this. There is only a small amount of boilerplate code to add:
```cs
using UnityEngine;

class MyScript : MonoBehaviour
{
    // all of your normal MonoBehaviour code can go here

#if !UNITY_EDITOR
    public TestMB(IntPtr ptr) : base(ptr) { }
#endif
}
```
the `#if` instruction means that this code should compile in both the Unity Editor and in a MelonLoader mod, so that you can keep your code unified and test in the editor with ease.

### Injecting a custom MonoBehaviour
This is what this mod is used for, and it is very simple:
```cs
FieldInjector.SerialisationHandler.Inject<MyScript>();
```
in the `OnApplicationStart` method is all that is needed. Do not register the class in Il2Cpp with MelonLoader or UnhollowerBaseLib - this mod does that itself and it won't be able to inject the class with fields if it's already injected without fields. Makers of frameworks that load code should consider registering fields for loaded behaviours automatically.

### Using them in Custom Items / Maps / etc

No extra work should be required to use the injected behaviours in asset bundles. Simply attach the component and it will load in the game.